defmodule Lighthouse.Client do
  use GenServer
  require Logger

  def start_link(opts) do
    GenServer.start_link(__MODULE__, opts)
  end

  def init(opts) do
    send(self(), :connect)
    {:ok, Map.merge(%{}, opts)}
  end

  def handle_info(:connect, state) do
    Logger.info("Lighthouse attempting connection")

    with {:ok, pid} <-
           Riptide.Client.start_link(state.url, [Lighthouse.Client.Commands.Console],
             name: Lighthouse
           ),
         auth =
           Map.merge(
             %{
               token: "unknown",
               node: :inet.gethostname() |> elem(1) |> String.Chars.to_string(),
               tags: %{}
             },
             state
           ),
         {:ok, pid} <- Riptide.Client.call(Lighthouse, "auth.node", auth) do
      Logger.info("Lighthouse authenticated")
    else
      _ -> Process.send_after(self(), :connect, :timer.seconds(5))
    end

    {:noreply, state}
  end
end
